@@ -45,8 +45,6 @@
 #include <QClipboard>
 
 #include <KLineEdit>
-//#include <collection.h>
-//#include <itemcreatejob.h>
 #include <kcombobox.h>
 #include <kconfig.h>
 #include <kconfiggroup.h>
@@ -240,16 +238,17 @@ public:
         ServerRole = Qt::UserRole + 1
     };
 
-    ContactListModel(QObject *parent)
+    explicit ContactListModel(QObject *parent)
         : QAbstractTableModel(parent)
     {
     }
 
     void addContact(const KLDAP::LdapAttrMap &contact, const QString &server)
     {
+        beginResetModel();
         mContactList.append(contact);
         mServerList.append(server);
-        reset();
+        endResetModel();
     }
 
     QPair<KLDAP::LdapAttrMap, QString> contact(const QModelIndex &index) const
@@ -281,9 +280,10 @@ public:
 
     void clear()
     {
+        beginResetModel();
         mContactList.clear();
         mServerList.clear();
-        reset();
+        endResetModel();
     }
 
     int rowCount(const QModelIndex &parent = QModelIndex()) const override
@@ -304,7 +304,7 @@ public:
         }
     }
 
-    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override
     {
         if (orientation == Qt::Vertical || role != Qt::DisplayRole || section < 0 || section > 17) {
             return QVariant();
@@ -313,62 +313,43 @@ public:
         switch (section) {
         case 0:
             return i18n("Full Name");
-            break;
         case 1:
             return i18nc("@title:column Column containing email addresses", "Email");
-            break;
         case 2:
             return i18n("Home Number");
-            break;
         case 3:
             return i18n("Work Number");
-            break;
         case 4:
             return i18n("Mobile Number");
-            break;
         case 5:
             return i18n("Fax Number");
-            break;
         case 6:
             return i18n("Company");
-            break;
         case 7:
             return i18n("Organization");
-            break;
         case 8:
             return i18n("Street");
-            break;
         case 9:
             return i18nc("@title:column Column containing the residential state of the address",
                          "State");
-            break;
         case 10:
             return i18n("Country");
-            break;
         case 11:
             return i18n("Zip Code");
-            break;
         case 12:
             return i18n("Postal Address");
-            break;
         case 13:
             return i18n("City");
-            break;
         case 14:
             return i18n("Department");
-            break;
         case 15:
             return i18n("Description");
-            break;
         case 16:
             return i18n("User ID");
-            break;
         case 17:
             return i18nc("@title:column Column containing title of the person", "Title");
-            break;
         default:
             return QVariant();
-            break;
         }
 
         return QVariant();
@@ -398,61 +379,42 @@ public:
         switch (index.column()) {
         case 0:
             return join(map.value(QStringLiteral("cn")), QStringLiteral(", "));
-            break;
         case 1:
             return join(map.value(QStringLiteral("mail")), QStringLiteral(", "));
-            break;
         case 2:
             return join(map.value(QStringLiteral("homePhone")), QStringLiteral(", "));
-            break;
         case 3:
             return join(map.value(QStringLiteral("telephoneNumber")), QStringLiteral(", "));
-            break;
         case 4:
             return join(map.value(QStringLiteral("mobile")), QStringLiteral(", "));
-            break;
         case 5:
             return join(map.value(QStringLiteral("facsimileTelephoneNumber")), QStringLiteral(", "));
-            break;
         case 6:
             return join(map.value(QStringLiteral("Company")), QStringLiteral(", "));
-            break;
         case 7:
             return join(map.value(QStringLiteral("o")), QStringLiteral(", "));
-            break;
         case 8:
             return join(map.value(QStringLiteral("street")), QStringLiteral(", "));
-            break;
         case 9:
             return join(map.value(QStringLiteral("st")), QStringLiteral(", "));
-            break;
         case 10:
             return join(map.value(QStringLiteral("co")), QStringLiteral(", "));
-            break;
         case 11:
             return join(map.value(QStringLiteral("postalCode")), QStringLiteral(", "));
-            break;
         case 12:
             return join(map.value(QStringLiteral("postalAddress")), QStringLiteral(", "));
-            break;
         case 13:
             return join(map.value(QStringLiteral("l")), QStringLiteral(", "));
-            break;
         case 14:
             return join(map.value(QStringLiteral("department")), QStringLiteral(", "));
-            break;
         case 15:
             return join(map.value(QStringLiteral("description")), QStringLiteral(", "));
-            break;
         case 16:
             return join(map.value(QStringLiteral("uid")), QStringLiteral(", "));
-            break;
         case 17:
             return join(map.value(QStringLiteral("title")), QStringLiteral(", "));
-            break;
         default:
             return QVariant();
-            break;
         }
 
         return QVariant();
@@ -468,19 +430,6 @@ class Q_DECL_HIDDEN LdapSearchDialog::Private
 public:
     Private(LdapSearchDialog *qq)
         : q(qq)
-        , mNumHosts(0)
-        , mIsConfigured(false)
-        , mFilterCombo(nullptr)
-        , mSearchType(nullptr)
-        , mSearchEdit(nullptr)
-        , mRecursiveCheckbox(nullptr)
-        , mResultView(nullptr)
-        , mSearchButton(nullptr)
-        , mModel(nullptr)
-        , progressIndication(nullptr)
-        , sortproxy(nullptr)
-        , searchLine(nullptr)
-        , user1Button(nullptr)
     {
     }
 
@@ -515,23 +464,23 @@ public:
     LdapSearchDialog *q;
     KGuiItem startSearchGuiItem;
     KGuiItem stopSearchGuiItem;
-    int mNumHosts;
+    int mNumHosts = 0;
     QList<KLDAP::LdapClient *> mLdapClientList;
-    bool mIsConfigured;
+    bool mIsConfigured = false;
     KContacts::Addressee::List mSelectedContacts;
 
-    KComboBox *mFilterCombo;
-    KComboBox *mSearchType;
-    QLineEdit *mSearchEdit;
+    KComboBox *mFilterCombo = nullptr;
+    KComboBox *mSearchType = nullptr;
+    QLineEdit *mSearchEdit = nullptr;
 
-    QCheckBox *mRecursiveCheckbox;
-    QTableView *mResultView;
-    QPushButton *mSearchButton;
-    ContactListModel *mModel;
-    KPIM::ProgressIndicatorLabel *progressIndication;
-    QSortFilterProxyModel *sortproxy;
-    KLineEdit *searchLine;
-    QPushButton *user1Button;
+    QCheckBox *mRecursiveCheckbox = nullptr;
+    QTableView *mResultView = nullptr;
+    QPushButton *mSearchButton = nullptr;
+    ContactListModel *mModel = nullptr;
+    KPIM::ProgressIndicatorLabel *progressIndication = nullptr;
+    QSortFilterProxyModel *sortproxy = nullptr;
+    KLineEdit *searchLine = nullptr;
+    QPushButton *user1Button = nullptr;
 };
 
 LdapSearchDialog::LdapSearchDialog(QWidget *parent)
@@ -539,8 +488,9 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     , d(new Private(this))
 {
     setWindowTitle(i18n("Import Contacts from LDAP"));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel, this);
     d->user1Button = new QPushButton;
     buttonBox->addButton(d->user1Button, QDialogButtonBox::ActionRole);
 
@@ -634,8 +584,9 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     d->mResultView->verticalHeader()->hide();
     d->mResultView->setSortingEnabled(true);
     d->mResultView->horizontalHeader()->setSortIndicatorShown(true);
-    connect(d->mResultView, SIGNAL(clicked(QModelIndex)),
-            SLOT(slotSelectionChanged()));
+    connect(d->mResultView, QOverload<const QModelIndex &>::of(&QTableView::clicked), this, [this]() {
+        d->slotSelectionChanged();
+    });
     topLayout->addWidget(d->mResultView);
 
     d->mResultView->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -651,18 +602,22 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     QDialogButtonBox *buttons = new QDialogButtonBox(page);
     QPushButton *button = buttons->addButton(i18n("Select All"),
                                              QDialogButtonBox::ActionRole);
-    connect(button, SIGNAL(clicked()), this, SLOT(slotSelectAll()));
+    connect(button, &QPushButton::clicked, this, [this]() {
+        d->slotSelectAll();
+    });
     button = buttons->addButton(i18n("Unselect All"),
                                 QDialogButtonBox::ActionRole);
-    connect(button, SIGNAL(clicked()), this, SLOT(slotUnselectAll()));
+    connect(button, &QPushButton::clicked, this, [this]() {
+        d->slotUnselectAll();
+    });
 
     buttonLayout->addWidget(buttons);
 
     d->user1Button->setText(i18n("Add Selected"));
     user2Button->setText(i18n("Configure LDAP Servers..."));
 
-    connect(d->mRecursiveCheckbox, SIGNAL(toggled(bool)),
-            this, SLOT(slotSetScope(bool)));
+    connect(d->mRecursiveCheckbox, &QCheckBox::toggled,
+            this, [this](bool state) { d->slotSetScope(state); });
     connect(d->mSearchButton, SIGNAL(clicked()),
             this, SLOT(slotStartSearch()));
 
@@ -748,7 +703,7 @@ void LdapSearchDialog::Private::restoreSettings()
 
             q->connect(ldapClient, SIGNAL(result(KLDAP::LdapClient,KLDAP::LdapObject)), q, SLOT(slotAddResult(KLDAP::LdapClient,KLDAP::LdapObject)));
             q->connect(ldapClient, SIGNAL(done()), q, SLOT(slotSearchDone()));
-            q->connect(ldapClient, SIGNAL(error(QString)), q, SLOT(slotError(QString)));
+            q->connect(ldapClient, &LdapClient::error, q, [this](const QString &err) {slotError(err);});
 
             mLdapClientList.append(ldapClient);
         }
@@ -925,13 +880,14 @@ void LdapSearchDialog::slotUser2()
 {
     // Configure LDAP servers
 
-    KCMultiDialog dialog(this);
-    dialog.setWindowTitle(i18n("Configure the Address Book LDAP Settings"));
-    dialog.addModule(QStringLiteral("kcmldap.desktop"));
+    QPointer<KCMultiDialog> dialog = new KCMultiDialog(this);
+    dialog->setWindowTitle(i18n("Configure the Address Book LDAP Settings"));
+    dialog->addModule(QStringLiteral("kcmldap.desktop"));
 
-    if (dialog.exec()) {   //krazy:exclude=crashy
+    if (dialog->exec()) {   //krazy:exclude=crashy
         d->restoreSettings();
     }
+    delete dialog;
 }
 
 void LdapSearchDialog::slotCancelClicked()
