@@ -36,16 +36,9 @@ using namespace KPIM;
 
 MultiplyingLineView::MultiplyingLineView(MultiplyingLineFactory *factory, MultiplyingLineEditor *parent)
     : QScrollArea(parent)
-    , mCurDelLine(nullptr)
     , mPage(new QWidget(this))
     , mTopLayout(new QVBoxLayout(this))
     , mMultiplyingLineFactory(factory)
-    , mLineHeight(0)
-    , mFirstColumnWidth(0)
-    , mCompletionMode(KCompletion::CompletionNone)
-    , mAutoResize(false)
-    , mDynamicSizeHint(true)
-    , mModified(false)
 {
     setWidgetResizable(true);
     setFrameStyle(QFrame::NoFrame);
@@ -138,7 +131,7 @@ void MultiplyingLineView::slotReturnPressed(MultiplyingLine *line)
 void MultiplyingLineView::slotDownPressed(MultiplyingLine *line)
 {
     int pos = mLines.indexOf(line);
-    if (pos >= (int)mLines.count() - 1) {
+    if (pos >= (mLines.count() - 1)) {
         Q_EMIT focusDown();
     } else if (pos >= 0) {
         activateLine(mLines.at(pos + 1));
@@ -321,7 +314,7 @@ bool MultiplyingLineView::isModified() const
     }
 
     QListIterator<MultiplyingLine *> it(mLines);
-    MultiplyingLine *line;
+    MultiplyingLine *line = nullptr;
     while (it.hasNext()) {
         line = it.next();
         if (line->isModified()) {
