@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,11 +26,10 @@ class KPIM::ProgressStatusBarWidgetPrivate
 {
 public:
     ProgressStatusBarWidgetPrivate()
-        : mLittleProgress(nullptr)
     {
     }
 
-    KPIM::StatusbarProgressWidget *mLittleProgress;
+    KPIM::StatusbarProgressWidget *mLittleProgress = nullptr;
 };
 
 ProgressStatusBarWidget::ProgressStatusBarWidget(QWidget *alignWidget, QWidget *parent, unsigned int showTypeProgressItem)
@@ -38,10 +37,12 @@ ProgressStatusBarWidget::ProgressStatusBarWidget(QWidget *alignWidget, QWidget *
     , d(new KPIM::ProgressStatusBarWidgetPrivate)
 {
     KPIM::ProgressDialog *progressDialog = new KPIM::ProgressDialog(alignWidget, parent);
+    progressDialog->setObjectName(QStringLiteral("progressDialog"));
     progressDialog->setShowTypeProgressItem(showTypeProgressItem);
     progressDialog->hide();
 
     d->mLittleProgress = new KPIM::StatusbarProgressWidget(progressDialog, alignWidget);
+    d->mLittleProgress->setObjectName(QStringLiteral("littleprogress"));
     d->mLittleProgress->setShowTypeProgressItem(showTypeProgressItem);
     d->mLittleProgress->show();
 }
