@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,15 +26,13 @@ AddresseeLineEditAkonadi::AddresseeLineEditAkonadi(AddresseeLineEditManager *add
     : m_akonadiSession(nullptr)
     , mAddressLineStatic(addressLineStatic)
 {
-
 }
 
 AddresseeLineEditAkonadi::~AddresseeLineEditAkonadi()
 {
-
 }
 
-Akonadi::Session *AddresseeLineEditAkonadi::akonadiSession()
+Akonadi::Session *AddresseeLineEditAkonadi::akonadiSession() const
 {
     if (!m_akonadiSession) {
         m_akonadiSession = new Akonadi::Session("contactsCompletionSession");
